DecodeError

Enum DecodeError 

pub enum DecodeError {
    Incomplete {
        needed: usize,
        available: usize,
    },
    InvalidMarker,
    InvalidLength {
        length: u16,
    },
    UnknownMessageType(u8),
    UnsupportedVersion {
        version: u8,
    },
    InvalidKeepaliveLength {
        length: u16,
    },
    MalformedField {
        message_type: &'static str,
        detail: String,
    },
    MalformedOptionalParameter {
        offset: usize,
        detail: String,
    },
    UpdateLengthMismatch {
        detail: String,
    },
    UpdateAttributeError {
        subcode: u8,
        data: Vec<u8>,
        detail: String,
    },
    InvalidNetworkField {
        detail: String,
        data: Vec<u8>,
    },
}
Errors encountered while decoding a BGP message from bytes.

Variants



Incomplete

Not enough bytes are available to decode the message.

Fields

needed: usize

Minimum bytes required.

available: usize

Bytes currently available.



InvalidMarker

The 16-byte header marker is not all 0xFF.



InvalidLength

Message length field is outside the valid range.

Fields

length: u16

The invalid length value from the wire.



UnknownMessageType(u8)

Message type byte is not a known BGP message type.

Tuple Fields

0: u8

The unrecognized type byte.



UnsupportedVersion

BGP version in OPEN is not 4.

Fields

version: u8

The version number received.



InvalidKeepaliveLength

KEEPALIVE message has an invalid length (must be exactly 19).

Fields

length: u16

The invalid length value.



MalformedField

A field within the message body is structurally invalid.

Fields

message_type: &'static str

Which message type contained the error.

detail: String

Human-readable description of the malformation.



MalformedOptionalParameter

An optional parameter in OPEN is malformed.

Fields

offset: usize

Byte offset within the optional parameters.

detail: String

Human-readable description of the error.



UpdateLengthMismatch

UPDATE withdrawn/attribute/NLRI length fields are inconsistent.

Fields

detail: String

Human-readable description of the mismatch.



UpdateAttributeError

UPDATE attribute fails RFC 4271 6.3 validation.

Fields

subcode: u8

NOTIFICATION subcode for this error.

data: Vec<u8>

Raw attribute bytes for the NOTIFICATION data field.

detail: String

Human-readable description of the error.



InvalidNetworkField

NLRI prefix encoding is invalid (RFC 4271 4.3).

Fields

detail: String

Human-readable description of the error.

data: Vec<u8>

Raw NLRI bytes for the NOTIFICATION data field.

Implementations

Source

impl DecodeError

pub fn to_notification(&self) -> (NotificationCode, u8, Bytes)

Returns the NOTIFICATION (code, subcode, data) that should be sent to the peer when this decode error is encountered.